-- From: https://gist.github.com/HoraceBury/9431861
-- converts a table of {x,y,x,y,...} to points {x,y}
function tableToPoints( tbl )
   local pts = {}	
   for i=1, #tbl-1, 2 do
      pts[#pts+1] = { x=tbl[i], y=tbl[i+1] }
   end	
   return pts
end

-- ensures that a list of coordinates is converted to a table of {x,y} points
-- returns a table of {x,y} points and the number of points, whether a display group or not
function ensurePointsTable( tbl )
   if (type(tbl[1]) == "number") then
      -- list contains {x,y,x,y,...} coordinates - convert to table of {x,y} 
      tbl = tableToPoints( tbl )
      return tbl, #tbl
   else
      -- table is already in {x,y} point format...
      -- check for display group
      local count = tbl.numChildren
      if (count == nil) then
         count = #tbl
      end
      return tbl, count
   end
end

function getBoundingCentroid( pts )
   pts = ensurePointsTable( pts ) -- EFM change a little
   local xMin, xMax, yMin, yMax = 100000000, -100000000, 100000000, -100000000
   for i=1, #pts do
      local pt = pts[i]
      if (pt.x < xMin) then xMin = pt.x end
      if (pt.x > xMax) then xMax = pt.x end
      if (pt.y < yMin) then yMin = pt.y end
      if (pt.y > yMax) then yMax = pt.y end
   end
   local width, height = xMax-xMin, yMax-yMin
   local cx, cy = xMin+(width/2), yMin+(height/2)
   local output = {
      centroid = { x=cx, y=cy },
      width = width,
      height = height,
      bounding = { xMin=xMin, xMax=xMax, yMin=yMin, yMax=yMax },
   }
   return output
end

function calculateVertexPosition( self, num )
   local vertX = self._vertices[(num-1)*2+1]
   local vertY = self._vertices[(num) * 2]
   return { x = vertX + self.x - self._boundingCentroid.centroid.x,
            y = vertY + self.y - self._boundingCentroid.centroid.x }
end

function getDistance(objA, objB)
    -- Get the length for each of the components x and y
    local xDist = objB.x - objA.x
    local yDist = objB.y - objA.y

    return math.sqrt( (xDist ^ 2) + (yDist ^ 2) ) 
end

